==> hippoagentsdk-0.0.2-sources.jar: com/hippoagent/fragments/UnassignedFragment.java <==
package com.hippoagent.fragments;//package com.fuguagent.fragments;
//
//import android.content.Intent;
//import android.os.Bundle;
//import androidx.annotation.Nullable;
//import androidx.fragment.app.Fragment;
//import androidx.swiperefreshlayout.widget.SwipeRefreshLayout;
//import androidx.recyclerview.widget.DefaultItemAnimator;
//import androidx.recyclerview.widget.LinearLayoutManager;
//import androidx.recyclerview.widget.RecyclerView;
//import android.view.LayoutInflater;
//import android.view.View;
//import android.view.ViewGroup;
//import android.widget.LinearLayout;
//
//import com.fuguagent.MyApplication;
//import com.fuguagent.R;
//import com.fuguagent.activities.FuguChatActivity;
//import com.fuguagent.activities.MainActivity;
//import com.fuguagent.adapters.UnassignedChatAdapter;
//import com.fuguagent.model.Conversation;
//import com.fuguagent.com.hippoagentsdk.utils.Constants;
//import com.fuguagent.com.hippoagentsdk.utils.Log;
//import com.google.gson.Gson;
//
//import java.util.ArrayList;
//import java.util.List;
//
///**
// * Created by ankit on 29/05/17.
// */
//
//public class UnassignedFragment extends Fragment implements SwipeRefreshLayout.OnRefreshListener {
//
//    private View root;
//    private SwipeRefreshLayout srLayout;
//    private RecyclerView rvUnassigned;
//    private UnassignedChatAdapter unassignedChatAdapter;
//    private ArrayList<Object> unassignedList = new ArrayList<>();
//    LinearLayoutManager layoutManager;
//    int pastVisiblesItems, visibleItemCount, totalItemCount, pageCount, countRecords;
//    private boolean hasMorePages;
//    private LinearLayout llNoConversation;
//
//    public UnassignedFragment() {
//    }
//
//    @Nullable
//    @Override
//    public View onCreateView(LayoutInflater inflater, @Nullable ViewGroup container, @Nullable Bundle savedInstanceState) {
//        root = inflater.inflate(R.layout.unassigned_fragment, container, false);
//        return root;
//    }
//
//    @Override
//    public void onViewCreated(View view, @Nullable Bundle savedInstanceState) {
//        super.onViewCreated(view, savedInstanceState);
//
//        srLayout = (SwipeRefreshLayout) root.findViewById(R.id.srLayout);
//        srLayout.setOnRefreshListener(this);
//        srLayout.setColorSchemeResources(R.color.white);
//        srLayout.setProgressBackgroundColorSchemeResource(R.color.colorPrimary);
//        srLayout.setSize(SwipeRefreshLayout.DEFAULT);
//        llNoConversation = (LinearLayout) root.findViewById(R.id.llNoConversation);
//        rvUnassigned = (RecyclerView) root.findViewById(R.id.rvUnassigned);
//        layoutManager = new LinearLayoutManager(getActivity());
//        rvUnassigned.setLayoutManager(layoutManager);
//        rvUnassigned.setItemAnimator(new DefaultItemAnimator());
//        rvUnassigned.setHasFixedSize(false);
//
//        unassignedChatAdapter = new UnassignedChatAdapter(unassignedList, getActivity(), new UnassignedChatAdapter.Callback() {
//            @Override
//            public void onClick(int position, Conversation conversation) {
//                conversation.setUnreadCount(0);
//                unassignedChatAdapter.notifyDataSetChanged();
//                setUnassignedChatConversationCount(conversation);
//                Intent chatIntent = new Intent(getActivity(), FuguChatActivity.class);
//                chatIntent.putExtra(Constants.CONVERSATION, new Gson().toJson(conversation, Conversation.class));
//                startActivityForResult(chatIntent, 100);
//            }
//        });
//        rvUnassigned.setAdapter(unassignedChatAdapter);
//
//        if(unassignedList.size() == 0){
//            llNoConversation.setVisibility(View.VISIBLE);
//        } else{
//            llNoConversation.setVisibility(View.GONE);
//        }
//
//        rvUnassigned.addOnScrollListener(new RecyclerView.OnScrollListener() {
//            @Override
//            public void onScrollStateChanged(RecyclerView recyclerView, int newState) {
//                super.onScrollStateChanged(recyclerView, newState);
//            }
//
//            @Override
//            public void onScrolled(RecyclerView recyclerView, int dx, int dy) {
//                //To implement Pagination
//                if (dy > 0) {
//                    visibleItemCount = layoutManager.getChildCount();
//                    totalItemCount = layoutManager.getItemCount();
//                    pastVisiblesItems = layoutManager.findFirstVisibleItemPosition();
//
//                    if(!((MainActivity)getActivity()).getHomeFragment().isPagingApiInProgress()) {
//                        if ((visibleItemCount + pastVisiblesItems) >= totalItemCount) {
//                            fetchNextPage();
//                        }
//                    }
//                }
//            }
//        });
//
//    }
//
//    public SwipeRefreshLayout getSrLayout() {
//        return srLayout;
//    }
//
//    private void fetchNextPage() {
//        ((MainActivity)getActivity()).getHomeFragment().setPagingApiInProgress(true);
//        toggleProgressBarVisibility(true);
//        int pageStart = unassignedList.size();
//        if (unassignedList.contains(progressBarItem)) {
//            pageStart = unassignedList.size();
//        }
//        ((MainActivity)getActivity()).getHomeFragment().apiGetConversation(String.valueOf(MyApplication.getInstance().getUserData().getUserId()),((MainActivity)getActivity()).getStatusIntArray()
//                , ((MainActivity)getActivity()).getTypeIntArray(), ((MainActivity)getActivity()).getLabelsIntArray(), pageStart, true, true,true);
//    }
//
//    private void setUnassignedChatConversationCount(Conversation conversationCount){
//        /*for(Conversation conversation : ((MainActivity)getActivity()).getHomeFragment().getUnassignedChatList()){
//            if(conversation.getChannelId().equals(conversationCount.getChannelId())){
//                conversation.setUnreadCount(0);
//                break;
//            }
//        }*/
//    }
//
//
//    @Override
//    public void onActivityResult(int requestCode, int resultCode, Intent data) {
//        super.onActivityResult(requestCode, resultCode, data);
//        Log.v("onActivityResult", "enter");
//        if(requestCode == 100){
////            ((MainActivity)getActivity()).getHomeFragment().apiGetConversation(((MainActivity)getActivity()).getMessageMod()
////                    , ConversationMode.UNASSIGNED.getOrdinal(), 1, false, true);
//        }
//    }
//
//    private UnassignedChatAdapter.ProgressBarItem progressBarItem;
//
//    public void toggleProgressBarVisibility(boolean isVisible) {
//        if (isVisible) {
//            if (progressBarItem == null) {
//                progressBarItem = new UnassignedChatAdapter.ProgressBarItem();
//            }
//            if (!unassignedList.contains(progressBarItem)) {
//                unassignedList.add(progressBarItem);
//                unassignedChatAdapter.notifyItemInserted(unassignedList.size() - 1);
//            }
//        } else {
//            if (progressBarItem != null && unassignedList.contains(progressBarItem)) {
//                unassignedList.remove(progressBarItem);
//                unassignedChatAdapter.notifyItemRemoved(unassignedList.size() - 1);
//            }
//        }
//    }
//
//    private ArrayList<Object> getAdapterList(List<Conversation> unassignedDetailList) {
//        if (unassignedList == null) {
//            unassignedList = new ArrayList<>();
//        }
//        unassignedList.clear();
//
//        if (unassignedDetailList != null && unassignedDetailList.size() > 0) {
//            unassignedList.addAll(unassignedDetailList);
//        }
//        return unassignedList;
//    }
//
//    public void setUnassignedChatData(final ArrayList<Conversation> unassignedChatData, boolean isPagination) {
//        if(!isPagination) {
//            unassignedList.clear();
//        }
//        unassignedList.addAll(unassignedChatData);
//        if (getView() != null && unassignedChatAdapter != null) {
//            getActivity().runOnUiThread(new Runnable() {
//                @Override
//                public void run() {
//                    unassignedChatAdapter.notifyDataSetChanged();
//                }
//            });
//        }
//
//        if(llNoConversation != null) {
//            if (unassignedList.size() == 0) {
//                llNoConversation.setVisibility(View.VISIBLE);
//            } else {
//                llNoConversation.setVisibility(View.GONE);
//            }
//        }
//    }
//
//
//    @Override
//    public void onRefresh() {
//        ((MainActivity)getActivity()).getHomeFragment().apiGetConversation(String.valueOf(MyApplication.getInstance().getUserData().getUserId()),((MainActivity)getActivity()).getStatusIntArray()
//                , ((MainActivity)getActivity()).getTypeIntArray(), ((MainActivity)getActivity()).getLabelsIntArray(), 1, false, false,true);
//    }
//
//}

==> hippoagentsdk-0.0.43-sources.jar: com/hippoagent/fragments/UnassignedFragment.java <==
package com.hippoagent.fragments;//package com.fuguagent.fragments;
//
//import android.content.Intent;
//import android.os.Bundle;
//import androidx.annotation.Nullable;
//import androidx.fragment.app.Fragment;
//import androidx.swiperefreshlayout.widget.SwipeRefreshLayout;
//import androidx.recyclerview.widget.DefaultItemAnimator;
//import androidx.recyclerview.widget.LinearLayoutManager;
//import androidx.recyclerview.widget.RecyclerView;
//import android.view.LayoutInflater;
//import android.view.View;
//import android.view.ViewGroup;
//import android.widget.LinearLayout;
//
//import com.fuguagent.HippoApplication;
//import com.fuguagent.R;
//import com.fuguagent.activities.FuguChatActivity;
//import com.fuguagent.activities.MainActivity;
//import com.fuguagent.adapters.UnassignedChatAdapter;
//import com.fuguagent.model.Conversation;
//import com.fuguagent.com.hippoagentsdk.utils.Constants;
//import com.fuguagent.com.hippoagentsdk.utils.Log;
//import com.google.gson.Gson;
//
//import java.util.ArrayList;
//import java.util.List;
//
///**
// * Created by ankit on 29/05/17.
// */
//
//public class UnassignedFragment extends Fragment implements SwipeRefreshLayout.OnRefreshListener {
//
//    private View root;
//    private SwipeRefreshLayout srLayout;
//    private RecyclerView rvUnassigned;
//    private UnassignedChatAdapter unassignedChatAdapter;
//    private ArrayList<Object> unassignedList = new ArrayList<>();
//    LinearLayoutManager layoutManager;
//    int pastVisiblesItems, visibleItemCount, totalItemCount, pageCount, countRecords;
//    private boolean hasMorePages;
//    private LinearLayout llNoConversation;
//
//    public UnassignedFragment() {
//    }
//
//    @Nullable
//    @Override
//    public View onCreateView(LayoutInflater inflater, @Nullable ViewGroup container, @Nullable Bundle savedInstanceState) {
//        root = inflater.inflate(R.layout.unassigned_fragment, container, false);
//        return root;
//    }
//
//    @Override
//    public void onViewCreated(View view, @Nullable Bundle savedInstanceState) {
//        super.onViewCreated(view, savedInstanceState);
//
//        srLayout = (SwipeRefreshLayout) root.findViewById(R.id.srLayout);
//        srLayout.setOnRefreshListener(this);
//        srLayout.setColorSchemeResources(R.color.white);
//        srLayout.setProgressBackgroundColorSchemeResource(R.color.colorPrimary);
//        srLayout.setSize(SwipeRefreshLayout.DEFAULT);
//        llNoConversation = (LinearLayout) root.findViewById(R.id.llNoConversation);
//        rvUnassigned = (RecyclerView) root.findViewById(R.id.rvUnassigned);
//        layoutManager = new LinearLayoutManager(getActivity());
//        rvUnassigned.setLayoutManager(layoutManager);
//        rvUnassigned.setItemAnimator(new DefaultItemAnimator());
//        rvUnassigned.setHasFixedSize(false);
//
//        unassignedChatAdapter = new UnassignedChatAdapter(unassignedList, getActivity(), new UnassignedChatAdapter.Callback() {
//            @Override
//            public void onClick(int position, Conversation conversation) {
//                conversation.setUnreadCount(0);
//                unassignedChatAdapter.notifyDataSetChanged();
//                setUnassignedChatConversationCount(conversation);
//                Intent chatIntent = new Intent(getActivity(), FuguChatActivity.class);
//                chatIntent.putExtra(Constants.CONVERSATION, new Gson().toJson(conversation, Conversation.class));
//                startActivityForResult(chatIntent, 100);
//            }
//        });
//        rvUnassigned.setAdapter(unassignedChatAdapter);
//
//        if(unassignedList.size() == 0){
//            llNoConversation.setVisibility(View.VISIBLE);
//        } else{
//            llNoConversation.setVisibility(View.GONE);
//        }
//
//        rvUnassigned.addOnScrollListener(new RecyclerView.OnScrollListener() {
//            @Override
//            public void onScrollStateChanged(RecyclerView recyclerView, int newState) {
//                super.onScrollStateChanged(recyclerView, newState);
//            }
//
//            @Override
//            public void onScrolled(RecyclerView recyclerView, int dx, int dy) {
//                //To implement Pagination
//                if (dy > 0) {
//                    visibleItemCount = layoutManager.getChildCount();
//                    totalItemCount = layoutManager.getItemCount();
//                    pastVisiblesItems = layoutManager.findFirstVisibleItemPosition();
//
//                    if(!((MainActivity)getActivity()).getHomeFragment().isPagingApiInProgress()) {
//                        if ((visibleItemCount + pastVisiblesItems) >= totalItemCount) {
//                            fetchNextPage();
//                        }
//                    }
//                }
//            }
//        });
//
//    }
//
//    public SwipeRefreshLayout getSrLayout() {
//        return srLayout;
//    }
//
//    private void fetchNextPage() {
//        ((MainActivity)getActivity()).getHomeFragment().setPagingApiInProgress(true);
//        toggleProgressBarVisibility(true);
//        int pageStart = unassignedList.size();
//        if (unassignedList.contains(progressBarItem)) {
//            pageStart = unassignedList.size();
//        }
//        ((MainActivity)getActivity()).getHomeFragment().apiGetConversation(String.valueOf(HippoApplication.getInstance().getUserData().getUserId()),((MainActivity)getActivity()).getStatusIntArray()
//                , ((MainActivity)getActivity()).getTypeIntArray(), ((MainActivity)getActivity()).getLabelsIntArray(), pageStart, true, true,true);
//    }
//
//    private void setUnassignedChatConversationCount(Conversation conversationCount){
//        /*for(Conversation conversation : ((MainActivity)getActivity()).getHomeFragment().getUnassignedChatList()){
//            if(conversation.getChannelId().equals(conversationCount.getChannelId())){
//                conversation.setUnreadCount(0);
//                break;
//            }
//        }*/
//    }
//
//
//    @Override
//    public void onActivityResult(int requestCode, int resultCode, Intent data) {
//        super.onActivityResult(requestCode, resultCode, data);
//        Log.v("onActivityResult", "enter");
//        if(requestCode == 100){
////            ((MainActivity)getActivity()).getHomeFragment().apiGetConversation(((MainActivity)getActivity()).getMessageMod()
////                    , ConversationMode.UNASSIGNED.getOrdinal(), 1, false, true);
//        }
//    }
//
//    private UnassignedChatAdapter.ProgressBarItem progressBarItem;
//
//    public void toggleProgressBarVisibility(boolean isVisible) {
//        if (isVisible) {
//            if (progressBarItem == null) {
//                progressBarItem = new UnassignedChatAdapter.ProgressBarItem();
//            }
//            if (!unassignedList.contains(progressBarItem)) {
//                unassignedList.add(progressBarItem);
//                unassignedChatAdapter.notifyItemInserted(unassignedList.size() - 1);
//            }
//        } else {
//            if (progressBarItem != null && unassignedList.contains(progressBarItem)) {
//                unassignedList.remove(progressBarItem);
//                unassignedChatAdapter.notifyItemRemoved(unassignedList.size() - 1);
//            }
//        }
//    }
//
//    private ArrayList<Object> getAdapterList(List<Conversation> unassignedDetailList) {
//        if (unassignedList == null) {
//            unassignedList = new ArrayList<>();
//        }
//        unassignedList.clear();
//
//        if (unassignedDetailList != null && unassignedDetailList.size() > 0) {
//            unassignedList.addAll(unassignedDetailList);
//        }
//        return unassignedList;
//    }
//
//    public void setUnassignedChatData(final ArrayList<Conversation> unassignedChatData, boolean isPagination) {
//        if(!isPagination) {
//            unassignedList.clear();
//        }
//        unassignedList.addAll(unassignedChatData);
//        if (getView() != null && unassignedChatAdapter != null) {
//            getActivity().runOnUiThread(new Runnable() {
//                @Override
//                public void run() {
//                    unassignedChatAdapter.notifyDataSetChanged();
//                }
//            });
//        }
//
//        if(llNoConversation != null) {
//            if (unassignedList.size() == 0) {
//                llNoConversation.setVisibility(View.VISIBLE);
//            } else {
//                llNoConversation.setVisibility(View.GONE);
//            }
//        }
//    }
//
//
//    @Override
//    public void onRefresh() {
//        ((MainActivity)getActivity()).getHomeFragment().apiGetConversation(String.valueOf(HippoApplication.getInstance().getUserData().getUserId()),((MainActivity)getActivity()).getStatusIntArray()
//                , ((MainActivity)getActivity()).getTypeIntArray(), ((MainActivity)getActivity()).getLabelsIntArray(), 1, false, false,true);
//    }
//
//}
